# -*- mode: makefile; coding: utf-8 -*-
# Copyright © 2003 Colin Walters <walters@debian.org>
# Copyright © 2004-2005 Jonas Smedegaard <dr@jones.dk>
# Description: configure, compile, binary, and clean Python libraries and programs
#  This class works for Python packages which use the Python
#  "distutils".  Note that optionally it can also use the
#  dh_python program which does some nice stuff.  See
#  the manual page for that program for more information.
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2, or (at
# your option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
# 02111-1307 USA.


ifndef _cdbs_bootstrap
_cdbs_scripts_path ?= /usr/lib/cdbs
_cdbs_rules_path ?= /usr/share/cdbs/1/rules
_cdbs_class_path ?= /usr/share/cdbs/1/class
endif

ifndef _cdbs_class_python_distutils
_cdbs_class_python_distutils := 1

## FIXME: Correct path when included officially!!!
#include $(_cdbs_class_path)/python-distutils-vars.mk$(_cdbs_makefile_suffix)
include debian/cdbs/1/class/python-distutils-vars.mk$(_cdbs_makefile_suffix)

# make: *** No rule to make target `voodoo'.  Stop.
# If no versioned python library packages found, grab all simpler ones
ifeq (,$(DEB_PYTHON_REAL_LIB_PACKAGES))
CDBS_BUILD_DEPENDS := $(CDBS_BUILD_DEPENDS), python-dev (>= $(DEB_PYTHON_DEFAULT_VERSION)), python-dev (<< $(DEB_PYTHON_NEXT_VERSION))
else
DEB_PYTHON_REAL_VERSIONS := $(filter-out -%,$(subst -, -,$(patsubst python%,%,$(DEB_PYTHON_REAL_LIB_PACKAGES))))
comma := ,
CDBS_BUILD_DEPENDS := $(CDBS_BUILD_DEPENDS), $(patsubst %,python%-dev$(comma),$(DEB_PYTHON_REAL_VERSIONS)) python
endif

cdbs_python_ver = $(filter-out -%,$(subst -, -,$(patsubst python%,%,$(cdbs_curpkg))))

common-build-arch common-build-indep:: common-build-impl
common-build-impl::
	cd $(DEB_SRCDIR) && /usr/bin/python$(DEB_PYTHON_COMPILE_VERSION) $(DEB_PYTHON_SETUP_CMD) build $(DEB_PYTHON_BUILD_ARGS)

clean::
# Ignore errors from this rule.  In a tarball build, the file
# may not exist.
# Try all flavors of Python used.
ifeq (,$(DEB_PYTHON_REAL_LIB_PACKAGES))
	-/usr/bin/python$(DEB_PYTHON_COMPILE_VERSION) $(DEB_PYTHON_SETUP_CMD) clean $(DEB_PYTHON_CLEAN_ARGS)
else
	-$(patsubst %, /usr/bin/python% $(DEB_PYTHON_SETUP_CMD) clean $(DEB_PYTHON_CLEAN_ARGS);, $(DEB_PYTHON_REAL_VERSIONS))
endif

# Use specific Python binary if needed
ifeq (,$(DEB_PYTHON_REAL_LIB_PACKAGES))
$(patsubst %,install/%,$(DEB_PYTHON_SIMPLE_PACKAGES)) :: install/% :
	cd $(DEB_SRCDIR) && /usr/bin/python$(DEB_PYTHON_COMPILE_VERSION) $(DEB_PYTHON_SETUP_CMD) install --root="$(DEB_PYTHON_DESTDIR)" $(DEB_PYTHON_INSTALL_ARGS_ALL) $(DEB_PYTHON_INSTALL_ARGS_$(cdbs_curpkg)
else
$(patsubst %,install/%,$(DEB_PYTHON_REAL_LIB_PACKAGES)) :: install/% :
	cd $(DEB_SRCDIR) && /usr/bin/python$(cdbs_python_ver) $(DEB_PYTHON_SETUP_CMD) install --root="$(DEB_PYTHON_DESTDIR)" $(DEB_PYTHON_INSTALL_ARGS_ALL) $(DEB_PYTHON_INSTALL_ARGS_$(cdbs_curpkg)
endif

# This class can optionally utilize debhelper's "dh_python" command.  Just
# be sure you include debhelper.mk before including this file.
ifdef _cdbs_rules_debhelper
ifneq (,$(strip $(filter 2.4,$(DEB_PYTHON_REAL_VERSIONS))))
# Python 2.4 support
CDBS_BUILD_DEPENDS := $(CDBS_BUILD_DEPENDS), debhelper (>= 4.2.28)
else
# Python 2.3 support
CDBS_BUILD_DEPENDS := $(CDBS_BUILD_DEPENDS), debhelper (>= 4.1.60)
endif

$(patsubst %,binary-install/%,$(DEB_PACKAGES)) :: binary-install/%:
	dh_python -p$(cdbs_curpkg)
endif

endif
